---
title: 관리자 콘솔은 2차 인증을 설정할 수 있나요?
category: 자주 묻는 질문 (일반 문의) > 관리자콘솔 > 관리자콘솔 문의
seo:
  title: 관리자 콘솔은 2차 인증을 설정할 수 있나요?
  description: 이중 보안을 위한 포트원 관리자콘솔의 2차 인증 설정방법 안내드립니다. 구글 OTP 앱 설치 방법까지 추가로 확인해보세요.
  keywords:
    - 관리자콘솔
tags:
  - 관리자콘솔
pgCompanies:
  - 공통
searchTags:
  - 구글OTP
  - 콘솔인증
  - 2차인증
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="" title="포트원 관리자콘솔의 이중 보안이 가능한 2차 인증 설정방법을 안내드립니다." />

#### **관리자콘솔 내 2차 인증 설정 경로**

- 포트원 관리자콘솔 > 상점·계정 관리 > 내 정보 관리 > 2차 인증

#### **구글 OTP 설치 방법**

1. 앱스토어에서 "Google Authenticator(Google OTP)" 앱 설치
   - [안드로이드 앱 설치 경로 ↗](https://play.google.com/store/apps/details?id=com.google.android.apps.authenticator2\&hl=ko)
   - [아이폰 앱 설치 경로 ↗](https://apps.apple.com/kr/app/google-authenticator/id388497605)
2. 설치한 앱의 오른쪽 '+'버튼 클릭
   - 안드로이드의 경우 하단에 위치
   - 아이폰의 경우 상단에 위치
3. 'QR코드 스캔' 선택 후 [포트원 관리자콘솔 ↗](https://admin.portone.io/auth/signin) 내 QR코드 스캔
4. 등록 완료!

#### **참고사항**

- QR코드는 페이지를 새로고침하는 경우 변경 됩니다. \
  (등록 진행시 페이지를 새로고침하는 경우 다시 QR코드를 리딩 해야 함)
- Google OTP앱에 발급되는 OTP 6자리 숫자는 30초마다 새로운 번호로 갱신 됩니다.
- 로그인 계정을 제 3자와 공유하여 이용하는 경우 아래와 같은 방법으로 추가 등록 가능합니다.

<Indent level="1">

1. 최초 등록한 사용자가 포트원 관리자콘솔 로그인
2. 관리자콘솔 > 시스템설정 > 의 하단 좌측 'TOTP 2차인증'의 QR코드를 새로운 기기로 스캔
3. 구글 OTP앱 OTP 6자리 숫자 발급 (최초 등록된 사용자와 동일한 번호 발급

</Indent>

- 등록된 QR코드는 변경되지 않으므로 제 3자와 공유시 OTP코드는 동일한 코드로 발급 됩니다.
- 최초 등록 후 2차 인증 기능 사용을 원하지 않는 경우, 등록된 사용자가 포트원 관리자콘솔 로그인을 한 후, 상점·계정 관리 > 내 정보 관리 2차인증 에 등록된 \[삭제] 버튼을 클릭하면 되며, 이후 로그인시 ID + PWD 만으로 로그인 가능 합니다.
